pub enum IntegratorActivity {
Inactive,
HoldIntegration,
Active,
}Expand description
The activity level of the PID controller’s integrator.
Details
During PID operation, the integrator could be paused, or disabled entirely. Pausing the integrator is useful when the integrator has already accumulated a useful amount of error enough to eliminate the steady state error but the system is entering a regime where noisy sensor feedback or rapid setpoint changes could cause the integrator to accumulate unwanted error.
Example
In an autopilot application, you could set integrator activity to
Inactivewhen the aircraft not under autopilot control at allHoldIntegrationwhen the aircraft is under autopilot control but below an altitude threshold (ground effect causes strong disturbances present in that region only)Activewhen the aircraft is under autopilot control and above the altitude threshold
Variants
Inactive
The integrator is disabled and the i-term set to zero
HoldIntegration
The integrator is paused and the i-term is held at the last value
Active
The integrator is active and the i-term is updated